Crate rtxtar

Crate rtxtar 

implementation of the txtar format.

origninally described by the golang tool of the same name

all text files are a valid txtar archive, there are no syntax errors.

Structs

Archive
a txtar archive.
ArchiveIter
File